@@ -184,23 +184,16 @@ def delete_temporary_bitop_keys(system='default'):
 
 
 #--- Events ----------------------------------------------
-class MixinEventsMisc:
+class MixinEventsMarked:
     """
     Extends with an obj.has_events_marked()
     that returns `True` if there are any events marked,
     otherwise `False` is returned.
-
-    Extens also with a obj.delete()
-    (useful for deleting temporary calculations).
     """
     def has_events_marked(self):
         cli = get_redis(self.system)
         return cli.get(self.redis_key) != None
 
-    def delete(self):
-        cli = get_redis(self.system)
-        cli.delete(self.redis_key)
-
 
 class MixinCounts:
     """
@@ -232,7 +225,7 @@ class MixinContains:
             return False
 
 
-class MonthEvents(MixinCounts, MixinContains, MixinEventsMisc):
+class MonthEvents(MixinCounts, MixinContains, MixinEventsMarked):
     """
     Events for a month.
 
@@ -246,7 +239,7 @@ class MonthEvents(MixinCounts, MixinContains, MixinEventsMisc):
                                      '%s-%s' % (year, month))
 
 
-class WeekEvents(MixinCounts, MixinContains, MixinEventsMisc):
+class WeekEvents(MixinCounts, MixinContains, MixinEventsMarked):
     """
     Events for a week.
 
@@ -259,7 +252,7 @@ class WeekEvents(MixinCounts, MixinContains, MixinEventsMisc):
         self.redis_key = _prefix_key(event_name, 'W%s-%s' % (year, week))
 
 
-class DayEvents(MixinCounts, MixinContains, MixinEventsMisc):
+class DayEvents(MixinCounts, MixinContains, MixinEventsMarked):
     """
     Events for a day.
 
@@ -273,7 +266,7 @@ class DayEvents(MixinCounts, MixinContains, MixinEventsMisc):
                                      '%s-%s-%s' % (year, month, day))
 
 
-class HourEvents(MixinCounts, MixinContains, MixinEventsMisc):
+class HourEvents(MixinCounts, MixinContains, MixinEventsMarked):
     """
     Events for a hour.
 
@@ -334,17 +327,17 @@ class BitOperation:
         cli.bitop(op_name, self.redis_key, *event_redis_keys)
 
 
-class BitOpAnd(BitOperation, MixinContains, MixinCounts, MixinEventsMisc):
+class BitOpAnd(BitOperation, MixinContains, MixinCounts):
 
     def __init__(self, system_or_event, *events):
         BitOperation.__init__(self, 'AND', system_or_event, *events)
 
-class BitOpOr(BitOperation, MixinContains, MixinCounts, MixinEventsMisc):
+class BitOpOr(BitOperation, MixinContains, MixinCounts):
 
     def __init__(self, system_or_event, *events):
         BitOperation.__init__(self, 'OR', system_or_event, *events)
 
-class BitOpXor(BitOperation, MixinContains, MixinCounts, MixinEventsMisc):
+class BitOpXor(BitOperation, MixinContains, MixinCounts):
 
     def __init__(self, system_or_event, *events):
         BitOperation.__init__(self, 'XOR', system_or_event, *events)
